# coding=utf-8
import tablestore as ots
import json
import random
import sys
from sls import ebike


GEO_TABLE_NAME = "geo"

OTS_INSTANCE = "fc-ots-sandbox"
OTS_ENDPOINT = "http://%s.cn-shanghai.ots.aliyuncs.com" % OTS_INSTANCE

lock_err_map = {
    0 : "ok",
    1 : "forbidden",
}

def req_lock(event, context):
    """
        event = {
            "Uid" : 100000,
            "DeviceId" : 123456,
            "Mobile" : "18612345678",
            "SessionId" : 100000001,
            "Logitude": 120.0776645,
            "Latitude": 30.131852
        }
        ret = {
            "SessionId" : 100000001,
            "Code" : 0,
            "Msg" : "ok",
            "Fee" : 234,
        }
    """
    ev = json.loads(event)
    ebike.sls_lock(context)
    code = 0
    sessionId = ev["SessionId"]
    creds = context.credentials
    akid, aksec = creds.access_key_id, creds.access_key_secret
    token = creds.security_token
    fee = get_fee(sessionId, akid, aksec, token)
    return  {
        "SessionId": sessionId,
        "Code" : code,
        "Msg" : lock_err_map[code],
        "Fee" : fee,
    }


def get_fee(sid, akid, aksec, token):
    mapList = get_geo(sid, akid, aksec, token)
    distance = 0
    for k, v in enumerate(mapList):
        dis = v["Distance"]
        distance += dis
    return distance * 0.001

def get_geo(sid, akid, aksec, token):
    consumed_counter = ots.CapacityUnit(0, 0)
    inclusive_start_primary_key = [('Uid', ots.INF_MIN), ('Sid', ots.INF_MIN), ('CreateTime', ots.INF_MIN),]
    exclusive_end_primary_key = [('Uid', ots.INF_MAX), ('Sid', ots.INF_MAX), ('CreateTime', ots.INF_MAX)]

    cond = ots.SingleColumnCondition("Sid", sid, ots.ComparatorType.EQUAL)
    limit = None
    columns_to_get = []

    client = ots.OTSClient(OTS_ENDPOINT, akid, aksec, OTS_INSTANCE, sts_token=token)
    range_iter = client.xget_range(
        GEO_TABLE_NAME, ots.Direction.FORWARD,
        inclusive_start_primary_key, exclusive_end_primary_key,
        consumed_counter, columns_to_get, limit,
        column_filter = cond, max_version = 1
    )
    return iterToMapList(range_iter)

def iterToMapList(range_iter):
    retMapList = []
    for row in range_iter:
        item = {}
        for it in row.attribute_columns:
            item[it[0]] = it[1]
        for it in row.primary_key:
            item[it[0]] = it[1]
        retMapList.append(item)
    return retMapList


